@@ -308,6 +308,9 @@ class SessionClient(adapter.LegacyJsonAdapter):
         redirect = kwargs.get('redirect')
         kwargs.setdefault('user_agent', USER_AGENT)
 
+        headers = kwargs.setdefault('headers', {})
+        headers.setdefault('Content-Type', 'application/json')
+
         if 'data' in kwargs:
             kwargs['data'] = jsonutils.dumps(kwargs['data'])
 
@@ -337,7 +340,7 @@ class SessionClient(adapter.LegacyJsonAdapter):
             raise exc.InvalidEndpoint(message=message)
         if (self.endpoint_override is not None and
                 location.lower().startswith(self.endpoint_override.lower())):
-                return location[len(self.endpoint_override):]
+            return location[len(self.endpoint_override):]
         else:
             return location
 
