@@ -11,11 +11,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import base64
 import json
 import tempfile
 
 import mock
+from oslo_serialization import base64
 import six
 from six.moves.urllib import error
 import testtools
@@ -127,6 +127,18 @@ class ShellEnvironmentTest(testtools.TestCase):
             mock.call('file:///home/my/dir/a.yaml')
         ])
 
+    def test_process_multiple_environment_files_container(self):
+
+        env_list_tracker = []
+        env_paths = ['/home/my/dir/env.yaml']
+        files, env = template_utils.process_multiple_environments_and_files(
+            env_paths, env_list_tracker=env_list_tracker,
+            fetch_env_files=False)
+
+        self.assertEqual(env_paths, env_list_tracker)
+        self.assertEqual({}, files)
+        self.assertEqual({}, env)
+
     @mock.patch('six.moves.urllib.request.urlopen')
     def test_process_environment_relative_file_up(self, mock_url):
 
@@ -715,7 +727,7 @@ class TestGetTemplateContents(testtools.TestCase):
                           'content': {'get_file': url},
                           'encoding': 'b64'}]}}}}}
         with mock.patch('six.moves.urllib.request.urlopen') as mock_url:
-            raw_content = base64.decodestring(content)
+            raw_content = base64.decode_as_bytes(content)
             response = six.BytesIO(raw_content)
             mock_url.return_value = response
             files = {}
@@ -732,8 +744,8 @@ t9SdXgLAAEE\n6AMAAATpAwAAaGVhdApQSwECHgMKAAAAAABGWVpEWzgLgQUAAAAF\
 AAAACAAYAAAAAAABAAAApIEA\nAAAAaGVhdC50eHRVVAUAAxRbDVN1eAsAAQToAwA\
 ABOkDAABQSwUGAAAAAAEAAQBOAAAARwAAAAAA\n'''
         # zip has '\0' in stream
-        self.assertIn(b'\0', base64.decodestring(content))
-        decoded_content = base64.decodestring(content)
+        self.assertIn(b'\0', base64.decode_as_bytes(content))
+        decoded_content = base64.decode_as_bytes(content)
         if six.PY3:
             self.assertRaises(UnicodeDecodeError, decoded_content.decode)
         else:
@@ -748,8 +760,8 @@ ABOkDAABQSwUGAAAAAAEAAQBOAAAARwAAAAAA\n'''
         filename = 'heat.utf16'
         content = b'//4tTkhTCgA=\n'
         # utf6 has '\0' in stream
-        self.assertIn(b'\0', base64.decodestring(content))
-        decoded_content = base64.decodestring(content)
+        self.assertIn(b'\0', base64.decode_as_bytes(content))
+        decoded_content = base64.decode_as_bytes(content)
         if six.PY3:
             self.assertRaises(UnicodeDecodeError, decoded_content.decode)
         else:
@@ -763,8 +775,8 @@ ABOkDAABQSwUGAAAAAAEAAQBOAAAARwAAAAAA\n'''
         filename = 'heat.gb18030'
         content = b'1tDO5wo=\n'
         # gb18030 has no '\0' in stream
-        self.assertNotIn('\0', base64.decodestring(content))
-        decoded_content = base64.decodestring(content)
+        self.assertNotIn('\0', base64.decode_as_bytes(content))
+        decoded_content = base64.decode_as_bytes(content)
         if six.PY3:
             self.assertRaises(UnicodeDecodeError, decoded_content.decode)
         else:
